# Fastlife

[![CI](https://github.com/mardiros/fastlife/actions/workflows/main.yml/badge.svg)](https://github.com/mardiros/fastlife/actions/workflows/main.yml)

[![codecov](https://codecov.io/gh/mardiros/fastlife/graph/badge.svg?token=DTpi73d7mf)](https://codecov.io/gh/mardiros/fastlife)


A high-level Python web framework based on FastAPI, Jinja2 and Pydandic and htmx.

The intention is to prototype fast application.

Under heavy development.


The package is available on pypi with the name fastlifeweb.
